import { Component, OnInit, ViewChild } from '@angular/core';
import { IgxDataChartComponent, IgxLineSeriesComponent, IgxStackedAreaSeriesComponent, IgxStackedFragmentSeriesComponent, IgxStackedLineSeriesComponent } from "igniteui-angular-charts";

@Component({
  selector: 'app-chart-page',
  templateUrl: './chart-page.component.html',
  styleUrls: ['./chart-page.component.scss']
})
export class ChartPageComponent implements OnInit {

  public data1: any[] = [];
  public data2: any[] = [];

  public valuePaths: string[] = ["StarWarsATAT", "StarWarsOrderAT", "MarvelTower", "MarvelMansion"];

  @ViewChild("chart", { static: true})
  public chart : IgxDataChartComponent;

  constructor() { }

  ngOnInit(): void {
    this.data1 = [
      { Scenario: 'Scenario A', Date: "Q1", StarWarsATAT: 5, StarWarsOrderAT: 4, MarvelTower: 3, MarvelMansion: 2 },
      { Scenario: 'Scenario A', Date: "Q2", StarWarsATAT: 4, StarWarsOrderAT: 5, MarvelTower: 4, MarvelMansion: 3 },
      { Scenario: 'Scenario A', Date: "Q3", StarWarsATAT: 3, StarWarsOrderAT: 4, MarvelTower: 5, MarvelMansion: 4 },
      { Scenario: 'Scenario A', Date: "Q4", StarWarsATAT: 4, StarWarsOrderAT: 3, MarvelTower: 4, MarvelMansion: 5 },
    ];

    this.data2 = [
      { Scenario: 'Scenario B', Date: "Q1", StarWarsATAT: 7, StarWarsOrderAT: 3, MarvelTower: 5, MarvelMansion: 4 },
      { Scenario: 'Scenario B', Date: "Q2", StarWarsATAT: 2, StarWarsOrderAT: 10, MarvelTower: 7, MarvelMansion: 9 },
      { Scenario: 'Scenario B', Date: "Q3", StarWarsATAT: 6, StarWarsOrderAT: 2, MarvelTower: 9, MarvelMansion: 5 },
      { Scenario: 'Scenario B', Date: "Q4", StarWarsATAT: 1, StarWarsOrderAT: 6, MarvelTower: 7, MarvelMansion: 3 }
    ];
  }

  private chartPopulated = false;
  public onChartRefreshCompleted(){
    if (!this.chartPopulated) {
      if (this.chart != null && this.chart.actualSeries != null && this.chart.actualSeries.length != 0) {
        this.chartPopulated = true;
        this.populateChart();
      }
    }
  }

  public populateChart(){
    let areaSeries : IgxStackedAreaSeriesComponent = this.chart.actualSeries[0] as IgxStackedAreaSeriesComponent;
    let lineSeries : IgxStackedLineSeriesComponent = this.chart.actualSeries[1] as IgxStackedLineSeriesComponent;

    for(let i=0; i<this.valuePaths.length; i++){
      let areaFragment = new IgxStackedFragmentSeriesComponent();
      areaFragment.valueMemberPath = this.valuePaths[i];
      areaFragment.title = "Scenario A " + this.valuePaths[i];
      areaSeries.series.add(areaFragment);

      let lineFragment = new IgxStackedFragmentSeriesComponent();
      lineFragment.valueMemberPath = this.valuePaths[i];
      lineFragment.title = "Scenario B " + this.valuePaths[i];
      lineSeries.series.add(lineFragment);
    }
  }
}
